/* ========================================
 *
 * main.c of CAN Bootloader0
 *
 * Behavior if there is no valid application:
 *    Wait for the bootload operation
 *
 * Behavior if there is a valid application:
 *    Wait for bootload operation for timeout (2000 ms) specified 
 *    in the Bootloader Component, else switch to the application. 
 *
 * ========================================
*/
#include <device.h>

int main()
{
   /* Start CAN Component, stop LED toggle clock */
   CyGlobalIntEnable;
   LCD_Start();
   LCD_ClearDisplay();
   LCD_Position(0u, 0u);  /* Set the position of LCD display to first row and first column */
   LCD_PrintString("BOOTLOADER");
   CAN_Start();	
   Clock_LED_Stop();
   
   /* Start the bootloader - all the bootload-related tasks are called from this function 
    * Note: The LEDs are toggled from the CyBtldrCommRead function in CAN_BOOT.c 
    */
   CyBtldr_Start();
   
   for(;;)
   {
      /* We never ever ever get here */
   }  /* end forever loop */
}     /* end main */

/* [] END OF FILE */
