/* ========================================
 * CAN Component:
 *    Receive mailbox0 (ID request) is assigned ID 0x01
 *    Receive mailbox1 (Reset) is assigned ID 0x02
 *    These IDs can be changed in the CAN Component customizer
 *
 * ========================================
*/
#include <device.h>

#define MAILBOX0  0                    /* Mailbox0 is ID cmd */
#define MAILBOX1  1                    /* Mailbox1 is reset cmd */

#define CAN_APPLICATION_RESET  0xAA    /* User defined. Data from the host received at Mailbox1 that indicates a reset */
#define CAN_APPLICATION_ID     0x88    /* User defined. Data from the host received at Mailbox0 that requests ID */

/* DEVICE_ID is defined by the Pins connected to the DeviceID status register */
#define DEVICE_ID  DeviceID_SR_Status

int main()
{
   /* Start CAN component and clear the Tx, Rx buffers & mailbox registers */
    CAN_Start();
	LCD_Start();
   
   /* clear CAN mailbox1 registers */
   CY_SET_REG32((reg32 *)CYDEV_CAN0_RX1_DH, 0u);
   CY_SET_REG32((reg32 *)CYDEV_CAN0_RX1_DL, 0u);
   
   CyGlobalIntEnable;
   
   for(;;)
   {
      /* Reset command received */
      if(CAN_RX_DATA_BYTE1(MAILBOX1) == CAN_APPLICATION_RESET)
      {
         LCD_ClearDisplay();
         LCD_PrintString("Rcvd Reset");
         
         /* Software Reset - this will switch to the bootloader for timeout specified in the bootloader Component */
         CY_SET_REG8(CYREG_RESET_CR2, 0x01);
      }
      else  /* Do application */
      {
         if(CAN_RX_DATA_BYTE1(MAILBOX0) == CAN_APPLICATION_ID)
         {
            CAN_TX_DATA_BYTE1(MAILBOX0) = DEVICE_ID;
            CAN_SendMsgID_Tx();	/* this is the CAN API to initiate a TX (CAN_TX_RX_func.c) */
            LCD_Position(1, 10);
      	    LCD_PrintString("ID");
            
            /* Clear MB 0 */
            CY_SET_REG32((reg32 *)CYDEV_CAN0_RX0_DH, 0u);
            CY_SET_REG32((reg32 *)CYDEV_CAN0_RX0_DL, 0u);
         }
         LCD_Position(0, 0);
      	LCD_PrintString("Bootload Success");
         LCD_Position(1, 0);
      	LCD_PrintString("Board 0");
      }
   }
}

/* [] END OF FILE */
