/* ========================================
 * DEVELOPMENT AND TESTING ONLY
 *
 *	I2C_CAN_Bridge.h
 *
 * Header file for PSoC3 I2C-to-CAN Bridge
 *
 * Copyright CYPRESS SEMICONDUCTOR, 2013
 * All Rights Reserved
 * UNPUBLISHED, LICENSED SOFTWARE.
 *
 * CONFIDENTIAL AND PROPRIETARY INFORMATION
 * WHICH IS THE PROPERTY OF Cypress Semiconductor.
 *
 *
 * STANDARD BTLD COMMAND PACKET FORMAT:
 * Multi byte entries are encoded in LittleEndian.
 * [1-byte] [1-byte ] [2-byte] [n-byte] [ 2-byte ] [1-byte]
 * [ 0x01 ] [Command] [ Size ] [ Data ] [Checksum] [ 0x17 ]
 * ========================================
 */
 
/*******************************************************************************
* User-defined parameters
********************************************************************************/
/* CAN comm. low-level parameters */
#define CAN_TX_DELAY          (1u)     /* This is a delay between CAN Tx retries */
#define WAIT_FOR_EOP				(100)		/* /us/ Delay to wait for to ensure a complete Bootload Command is received */
#define MAX_CAN_TX_RETRIES    (0xFF)   /* This parameter determines number of CAN Tx retries */

/* CAN application layer info: Data which defines a Reset and ID event - this is known by the satellite */
#define CAN_BOOTLOADER_RESET  (0xAA)
#define CAN_APPLICATION_ID    (0x88)

/* Buffer sizes */
#define I2C_BUFFER_SIZE       (80u)
#define CAN_RX_BUFFER_SIZE    (16u)    /* only 1st 2 bootload responses are longer than 7 bytes */


/*******************************************************************************
* Constants
********************************************************************************/
#define TRUE                  (1)
#define FALSE                 (0)

#define BTLDR_EOP             (0x17)	/* Bootloader end-of-packet is 0x17 - see header of this file */

/* Define mailbox numbers with more readable names */
#define MAILBOX0              (0)
#define MAILBOX1              (1)
#define MAILBOX2              (2)

#define ID_MASK               (uint32)(0x1FFFFFFF)	/* This ID mask is used to clear all but 3 MSbits from the Tx ID (this gives the ability to target upto 8 unique satellites) */

/* Macro defined to clear CAN registers used by the I2C-CAN bridge - keeps the main.c cleaner */
#define	CLEAR_CAN_REGISTERS	CY_SET_REG32((reg32 *)CYDEV_CAN0_TX0_DH, 0u);\
									   CY_SET_REG32((reg32 *)CYDEV_CAN0_TX0_DL, 0u);\	
									   CY_SET_REG32((reg32 *)CYDEV_CAN0_TX1_DH, 0u);\
									   CY_SET_REG32((reg32 *)CYDEV_CAN0_TX1_DL, 0u);\	
									   CY_SET_REG32((reg32 *)CYDEV_CAN0_TX2_DH, 0u);\
									   CY_SET_REG32((reg32 *)CYDEV_CAN0_TX2_DL, 0u);\	
									   CY_SET_REG32((reg32 *)CYDEV_CAN0_RX0_DH, 0u);\
									   CY_SET_REG32((reg32 *)CYDEV_CAN0_RX0_DL, 0u);\
									   CY_SET_REG32((reg32 *)CYDEV_CAN0_RX2_DH, 0u);\
									   CY_SET_REG32((reg32 *)CYDEV_CAN0_RX2_DL, 0u);


//[] END OF FILE
